1.2.2 (unreleased)
-------------------
*

1.2.1 (unreleased)
-------------------
* Bug 986112 - Use uploaded_files.json (instead of .txt) to track summary of uploaded files. [armenzg]

1.2.0 (2014-17-06)
-------------------
* Bug 986112 - Add the ability to track all files uploaded into summary file [armenzg]

1.1.7 (2014-24-05)
-------------------
* bug 998796 - fix positional argument bug [mtabara]

1.1.6 (2014-22-05)
-------------------
* Bug 1013631 - add missing certificate when get server whitelist [mtabara]

1.1.5 (2014-18-05)
-------------------
* Bug 998796 - sync filetypes whitelist with server [mtabara]

1.1.4 (2014-17-05)
-------------------
* Bug 1011518 - Don't try to open an already opened tempfile when compressing uploads. [jgraham]
* Bug 986032 - Fix dict key typo causing wrong mime-type to be set on compressed file [ahal]

1.1.3 (2014-24-04)
-------------------
* First numbered version

